SELECT
"Date",
"Year",
"QuarterNumber",
CONCAT("QuarterNumber", '/Q') as "Quarter",
"Year" * 10 + "QuarterNumber" AS "YearQuarterNumber",
CONCAT("Year", '-Q', "QuarterNumber") as "YearQuarter",
"MonthNumber",
"MonthName",
"MonthShortName",
"Year" * 100 + "MonthNumber" AS "YearMonthNumber",
CONCAT("Year", '-', "MonthShortNameLowerCase") AS "YearMonth",
CONCAT("MonthShortNameLowerCase", ' ', "Year") AS "MonthYear",
"WeekNumber",
YEAR(DATEADD(DAY, 26 - "WeekNumber", "Date")) * 100 + "WeekNumber" as "YearWeek",
"StartOfWeek",
"LastDayOfWeek",
"DayOfWeek",
"DayOfWeekName",
"DayOfMonth",
DATEPART(DAYOFYEAR, "Date") as "DayOfYear",
CAST(DATEADD(YEAR, DATEDIFF(YEAR, '19000101', "Date"), '19000101') AS DATE) as "StartOfYear",
CAST(DATEADD(YEAR, DATEDIFF(YEAR, '18991231', "Date"), '18991231') AS DATE) as "EndOfYear",
CAST(DATEADD(QUARTER, DATEDIFF(QUARTER, '19000101', "Date"), '19000101') AS DATE) as "StartOfQuarter",
CAST(DATEADD(QUARTER, DATEDIFF(QUARTER, '18991231', "Date"), '18991231') AS DATE) as "EndOfQuarter",
CAST(DATEADD(MONTH, DATEDIFF(MONTH, '19000101', "Date"), '19000101') AS DATE) as "StartOfMonth",
CAST(DATEADD(MONTH, DATEDIFF(MONTH, '18991231', "Date"), '18991231') AS DATE) as "EndOfMonth",
CONCAT(FORMAT("DayOfMonth", '00'), '.', FORMAT("MonthNumber", '00')) AS "DayMonth",
CONCAT(
    CONCAT(FORMAT(DAY("StartOfWeek"), '00'), '.', FORMAT(MONTH("StartOfWeek"), '00')), 
    '-', 
    CONCAT(FORMAT(DAY("LastDayOfWeek"), '00'), '.', FORMAT(MONTH("LastDayOfWeek"), '00'))
) AS "WeekPeriod",
CASE 
    WHEN "Date" = CAST(CURRENT_TIMESTAMP AS DATE) THEN N'Сегодня' ELSE CONVERT(NVARCHAR, "Date", 23)
END AS "CurrentDate",
CASE 
    WHEN "MonthNumber" = MONTH(CAST(CURRENT_TIMESTAMP AS DATE)) THEN N'Текущий месяц' ELSE "MonthShortName"
END AS "CurrentMonth",
CASE 
    WHEN "QuarterNumber" = DATEPART(QUARTER, CAST(CURRENT_TIMESTAMP AS DATE)) THEN N'Текущий квартал' ELSE CAST("QuarterNumber" AS NVARCHAR)
END AS "CurrentQuarter",
CASE 
    WHEN "Year" = YEAR(CAST(CURRENT_TIMESTAMP AS DATE)) THEN N'Текущий год' ELSE CAST("Year" AS NVARCHAR)
END AS "CurrentYear"
FROM
(
	SELECT *,
	DATEADD(DAY, 6, "StartOfWeek") as "LastDayOfWeek"
	FROM
	(
		SELECT *,
		DATEADD(DAY, 1 - "DayOfWeek", "Date") as "StartOfWeek",
		CASE 
		    WHEN "MonthNumber" = 1 THEN N'Январь'
		    WHEN "MonthNumber" = 2 THEN N'Февраль'
		    WHEN "MonthNumber" = 3 THEN N'Март'
		    WHEN "MonthNumber" = 4 THEN N'Апрель'
		    WHEN "MonthNumber" = 5 THEN N'Май'
		    WHEN "MonthNumber" = 6 THEN N'Июнь'
		    WHEN "MonthNumber" = 7 THEN N'Июль'
		    WHEN "MonthNumber" = 8 THEN N'Август'
		    WHEN "MonthNumber" = 9 THEN N'Сентябрь'
		    WHEN "MonthNumber" = 10 THEN N'Октябрь'
		    WHEN "MonthNumber" = 11 THEN N'Ноябрь'
		    WHEN "MonthNumber" = 12 THEN N'Декабрь'
		END AS "MonthName",
		CASE 
		    WHEN "MonthNumber" = 1 THEN N'Янв'
		    WHEN "MonthNumber" = 2 THEN N'Фев'
		    WHEN "MonthNumber" = 3 THEN N'Мар'
		    WHEN "MonthNumber" = 4 THEN N'Апр'
		    WHEN "MonthNumber" = 5 THEN N'Май'
		    WHEN "MonthNumber" = 6 THEN N'Июн'
		    WHEN "MonthNumber" = 7 THEN N'Июл'
		    WHEN "MonthNumber" = 8 THEN N'Авг'
		    WHEN "MonthNumber" = 9 THEN N'Сен'
		    WHEN "MonthNumber" = 10 THEN N'Окт'
		    WHEN "MonthNumber" = 11 THEN N'Ноя'
		    WHEN "MonthNumber" = 12 THEN N'Дек'
		END AS "MonthShortName",
		CASE 
		    WHEN "MonthNumber" = 1 THEN N'янв'
		    WHEN "MonthNumber" = 2 THEN N'фев'
		    WHEN "MonthNumber" = 3 THEN N'мар'
		    WHEN "MonthNumber" = 4 THEN N'апр'
		    WHEN "MonthNumber" = 5 THEN N'май'
		    WHEN "MonthNumber" = 6 THEN N'июн'
		    WHEN "MonthNumber" = 7 THEN N'июл'
		    WHEN "MonthNumber" = 8 THEN N'авг'
		    WHEN "MonthNumber" = 9 THEN N'сен'
		    WHEN "MonthNumber" = 10 THEN N'окт'
		    WHEN "MonthNumber" = 11 THEN N'ноя'
		    WHEN "MonthNumber" = 12 THEN N'дек'
		END AS "MonthShortNameLowerCase",
		CASE
		    WHEN "DayOfWeek" = 1 THEN N'Пн'
		    WHEN "DayOfWeek" = 2 THEN N'Вт'
		    WHEN "DayOfWeek" = 3 THEN N'Ср'
		    WHEN "DayOfWeek" = 4 THEN N'Чт'
		    WHEN "DayOfWeek" = 5 THEN N'Пт'
		    WHEN "DayOfWeek" = 6 THEN N'Сб'
		    WHEN "DayOfWeek" = 7 THEN N'Вс'
		END AS "DayOfWeekName"
		FROM
		(
			SELECT *,
			YEAR("Date") AS "Year",
			DATEPART(QUARTER, "Date") as "QuarterNumber",
			MONTH("Date") as "MonthNumber",
			DATEPART(ISO_WEEK, "Date") as "WeekNumber",
			(DATEPART(WEEKDAY, "Date") + @@DATEFIRST - 2) % 7 + 1  as "DayOfWeek",
			DAY("Date") as "DayOfMonth"
			FROM
			(
				SELECT DATEADD(DAY,	n - 1, CAST(<startDate> AS DATE)) AS "Date"
				FROM
				(
					SELECT Nums7.n * 1000000 + Nums6.n * 100000 + Nums5.n * 10000 + Nums4.n * 1000 + Nums3.n * 100 + Nums2.n * 10 + Nums1.n + 1 AS n
					FROM (VALUES(0),(1),(2),(3),(4),(5),(6),(7),(8),(9)) AS Nums1(n)
					CROSS JOIN (VALUES(0),(1),(2),(3),(4),(5),(6),(7),(8),(9)) AS Nums2(n)
					CROSS JOIN (VALUES(0),(1),(2),(3),(4),(5),(6),(7),(8),(9)) AS Nums3(n)
					CROSS JOIN (VALUES(0),(1),(2),(3),(4),(5),(6),(7),(8),(9)) AS Nums4(n)
					CROSS JOIN (VALUES(0),(1),(2),(3),(4),(5),(6),(7),(8),(9)) AS Nums5(n)
					CROSS JOIN (VALUES(0),(1),(2),(3),(4),(5),(6),(7),(8),(9)) AS Nums6(n)
					CROSS JOIN (VALUES(0),(1),(2),(3),(4),(5),(6),(7),(8),(9)) AS Nums7(n)
				) AS Nums
				WHERE n <= DATEDIFF(DAY, <startDate>, <endDate>) + 1
			) AS "Calendar1"
		) AS "Calendar2"
	) AS "Calendar3"
) AS "Calendar4"